"""
This is legacy code used only in the database migrations.
"""

from django.conf import settings
from django.db import models
from social_core.utils import setting_name

POSTGRES_JSONFIELD = getattr(settings, setting_name("POSTGRES_JSONFIELD"), False)

if POSTGRES_JSONFIELD:
    JSONFIELD_ENABLED = True
else:
    JSONFIELD_ENABLED = getattr(settings, setting_name("JSONFIELD_ENABLED"), False)

if JSONFIELD_ENABLED:
    JSONFIELD_CUSTOM = getattr(settings, setting_name("JSONFIELD_CUSTOM"), None)

    if JSONFIELD_CUSTOM is not None:
        try:
            from django.utils.module_loading import import_string
        except ImportError:
            from importlib import import_module as import_string
        JSONFieldBase = import_string(JSONFIELD_CUSTOM)
    else:
        try:
            from django.db.models import JSONField
        except ImportError:
            from django.contrib.postgres.fields import JSONField
else:
    JSONField = models.TextField



from io import StringIO

from django.core.management import call_command
from django.test import TestCase


class PendingMigrationsTests(TestCase):
    def test_no_pending_migrations(self):
        out = StringIO()
        try:
            call_command(
                "makemigrations",
                "--dry-run",
                "--check",
                stdout=out,
                stderr=StringIO(),
            )
        except SystemExit:  # pragma: no cover
            raise AssertionError("Pending migrations:\n" + out.getvalue()) from None



# Generated by Django 4.0 on 2023-06-10 07:10

import json

from django.db import migrations


def migrate_json_field(apps, schema_editor):
    UserSocialAuth = apps.get_model("social_django", "UserSocialAuth")
    Partial = apps.get_model("social_django", "Partial")
    db_alias = schema_editor.connection.alias
    for auth in UserSocialAuth.objects.using(db_alias).all():
        old_value = auth.extra_data
        if isinstance(old_value, str):
            try:
                old_value = json.loads(old_value)
            except json.JSONDecodeError as error:
                print(f"Failed to migrate extra_data {old_value}: {error}")
        auth.extra_data_new = old_value
        auth.save(update_fields=["extra_data_new"])
    for auth in Partial.objects.using(db_alias).all():
        old_value = auth.data
        if isinstance(old_value, str):
            try:
                old_value = json.loads(old_value)
            except json.JSONDecodeError as error:
                print(f"Failed to migrate data {old_value}: {error}")
        auth.data_new = old_value
        auth.save(update_fields=["data_new"])


class Migration(migrations.Migration):
    dependencies = [
        ("social_django", "0012_usersocialauth_extra_data_new"),
    ]

    operations = [
        migrations.RunPython(migrate_json_field, elidable=True),
    ]



# Generated by Django 4.0 on 2023-06-10 07:18

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("social_django", "0013_migrate_extra_data"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="usersocialauth",
            name="extra_data",
        ),
        migrations.RemoveField(
            model_name="partial",
            name="data",
        ),
    ]



# Generated by Django 4.0 on 2023-06-10 07:10

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("social_django", "0011_alter_id_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="usersocialauth",
            name="extra_data_new",
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="partial",
            name="data_new",
            field=models.JSONField(default=dict),
        ),
    ]
